*************************************************************
*                                                           *
*                Package PVzem                              *
*                                                           *
*   This package provides the PV functions in the limit     *
*   of zero external momentum. The conventions are as in    *
*   the FeynCalc and LoopTools packages.                    *
*                                                           *
*              Version 0.7.0 of  07/04/2003                 *
*                                                           *
*     Author: Jorge C. Romao                                *
*     e-mail: jorge.romao@ist.utl.pt                        *
*************************************************************
*  Functions included (at this moment):                     *
*                                                           *
*  b0zem(m02,m12)=b0(0,m02,m12)                             *
*  b1zem(m02,m12)=b1(0,m02,m12)                             *
*  c0zem(m02,m12,m22)=c0(0,0,0,m02,m12,m22)                 *
*  c1zem(m02,m12,m22)=cci(cc1,0,0,0,m02,m12,m22)            *
*  c2zem(m02,m12,m22)=cci(cc2,0,0,0,m02,m12,m22)            *
*  c11zem(m02,m12,m22)=cci(cc11,0,0,0,m02,m12,m22)          *
*  c22zem(m02,m12,m22)=cci(cc22,0,0,0,m02,m12,m22)          *
*  c12zem(m02,m12,m22)=cci(cc12,0,0,0,m02,m12,m22)          *
*  c00zem(m02,m12,m22)=cci(cc00,0,0,0,m02,m12,m22)          *
*                                                           *
*  where the functions on the right side are as in          *
*  LoopTools.                                               *
*                                                           *
*  For the functions that are divergent the following       *
*  COMMON block is used:                                    *
*                                                           *
*        common/UVIRPAR/Delta,mu2,lbd2                      *
*                                                           *
*  where the correspondance with LoopTools is as follows:   *
*                                                           *
*  Delta=getdelta()                                         *
*  mu2=getmudim()                                           *
*  lbd2=getlambda()                                         *
*                                                           *
*************************************************************     

        real*8 function b0zem(m02,m12)
        implicit none
        real*8 m02,m12
        real*8 r,eps,zeromass
        real*8 b0zemAB,b0zemAA

        zeromass=1.d-20
        m02=max(zeromass,m02)
        m12=max(zeromass,m12)

        r=m12/m02
        eps=1.0d-2
        
        if(abs(r-1.d0).lt.eps)then
           b0zem=b0zemAA(m02,m12)
           return
        else
           b0zem=b0zemAB(m02,m12)
           return
        endif

        write(*,*)'ERROR'

        return
        end

        real*8 function b1zem(m02,m12)
        implicit none
        real*8 m02,m12
        real*8 r,eps,zeromass
        real*8 b1zemAB,b1zemAA

        zeromass=1.d-20
        m02=max(zeromass,m02)
        m12=max(zeromass,m12)

        r=m12/m02
        eps=1.0d-2
        
        if(abs(r-1.d0).lt.eps)then
           b1zem=b1zemAA(m02,m12)
           return
        else
           b1zem=b1zemAB(m02,m12)
           return
        endif

        write(*,*)'ERROR'

        return
        end


        real*8 function c0zem(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2,eps,zeromass
        real*8 c0zemABC,c0zemABB,c0zemBAB,c0zemBBA,c0zemAAA

        zeromass=1.d-20
        m02=max(zeromass,m02)
        m12=max(zeromass,m12)
        m22=max(zeromass,m22)

        r1=m12/m02
        r2=m22/m02
        eps=1.0d-2
        
        if(abs(r1-1.d0).lt.eps)then
           if(abs(r2-1.d0).lt.eps)then
              c0zem=c0zemAAA(m02,m12,m22)
              return
           else
              c0zem=c0zemBBA(m02,m12,m22)
              return
           endif
        endif

        if(abs(r2-1.d0).lt.eps)then
           if(abs(r1-1.d0).lt.eps)then
              c0zem=c0zemAAA(m02,m12,m22)
              return
           else
              c0zem=c0zemBAB(m02,m12,m22)
              return
           endif
        endif

        if(abs(r1/r2-1.d0).lt.eps)then
           c0zem=c0zemABB(m02,m12,m22)
           return
        else
           c0zem=c0zemABC(m02,m12,m22)
           return
        endif

        write(*,*)'ERROR'

        return
        end


        real*8 function c1zem(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2,eps,zeromass
        real*8 c1zemABC,c1zemABB,c1zemBAB,c1zemBBA,c1zemAAA

        zeromass=1.d-20
        m02=max(zeromass,m02)
        m12=max(zeromass,m12)
        m22=max(zeromass,m22)

        r1=m12/m02
        r2=m22/m02
        eps=1.0d-2
        
        if(abs(r1-1.d0).lt.eps)then
           if(abs(r2-1.d0).lt.eps)then
              c1zem=c1zemAAA(m02,m12,m22)
              return
           else
              c1zem=c1zemBBA(m02,m12,m22)
              return
           endif
        endif

        if(abs(r2-1.d0).lt.eps)then
           if(abs(r1-1.d0).lt.eps)then
              c1zem=c1zemAAA(m02,m12,m22)
              return
           else
              c1zem=c1zemBAB(m02,m12,m22)
              return
           endif
        endif

        if(abs(r1/r2-1.d0).lt.eps)then
           c1zem=c1zemABB(m02,m12,m22)
           return
        else
           c1zem=c1zemABC(m02,m12,m22)
           return
        endif

        write(*,*)'ERROR'

        return
        end


        real*8 function c2zem(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2,eps,zeromass
        real*8 c2zemABC,c2zemABB,c2zemBAB,c2zemBBA,c2zemAAA

        zeromass=1.d-20
        m02=max(zeromass,m02)
        m12=max(zeromass,m12)
        m22=max(zeromass,m22)
        r1=m12/m02
        r2=m22/m02
        eps=1.0d-2
        
        if(abs(r1-1.d0).lt.eps)then
           if(abs(r2-1.d0).lt.eps)then
              c2zem=c2zemAAA(m02,m12,m22)
              return
           else
              c2zem=c2zemBBA(m02,m12,m22)
              return
           endif
        endif

        if(abs(r2-1.d0).lt.eps)then
           if(abs(r1-1.d0).lt.eps)then
              c2zem=c2zemAAA(m02,m12,m22)
              return
           else
              c2zem=c2zemBAB(m02,m12,m22)
              return
           endif
        endif

        if(abs(r1/r2-1.d0).lt.eps)then
           c2zem=c2zemABB(m02,m12,m22)
           return
        else
           c2zem=c2zemABC(m02,m12,m22)
           return
        endif

        write(*,*)'ERROR'

        return
        end


        real*8 function c11zem(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2,eps,zeromass
        real*8 c11zemABC,c11zemABB,c11zemBAB,c11zemBBA,c11zemAAA

        zeromass=1.d-20
        m02=max(zeromass,m02)
        m12=max(zeromass,m12)
        m22=max(zeromass,m22)
        r1=m12/m02
        r2=m22/m02
        eps=1.0d-2
        
        if(abs(r1-1.d0).lt.eps)then
           if(abs(r2-1.d0).lt.eps)then
              c11zem=c11zemAAA(m02,m12,m22)
              return
           else
              c11zem=c11zemBBA(m02,m12,m22)
              return
           endif
        endif

        if(abs(r2-1.d0).lt.eps)then
           if(abs(r1-1.d0).lt.eps)then
              c11zem=c11zemAAA(m02,m12,m22)
              return
           else
              c11zem=c11zemBAB(m02,m12,m22)
              return
           endif
        endif

        if(abs(r1/r2-1.d0).lt.eps)then
           c11zem=c11zemABB(m02,m12,m22)
           return
        else
           c11zem=c11zemABC(m02,m12,m22)
           return
        endif

        write(*,*)'ERROR'

        return
        end


        real*8 function c22zem(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2,eps,zeromass
        real*8 c22zemABC,c22zemABB,c22zemBAB,c22zemBBA,c22zemAAA

        zeromass=1.d-20
        m02=max(zeromass,m02)
        m12=max(zeromass,m12)
        m22=max(zeromass,m22)
        r1=m12/m02
        r2=m22/m02
        eps=1.0d-2
        
        if(abs(r1-1.d0).lt.eps)then
           if(abs(r2-1.d0).lt.eps)then
              c22zem=c22zemAAA(m02,m12,m22)
              return
           else
              c22zem=c22zemBBA(m02,m12,m22)
              return
           endif
        endif

        if(abs(r2-1.d0).lt.eps)then
           if(abs(r1-1.d0).lt.eps)then
              c22zem=c22zemAAA(m02,m12,m22)
              return
           else
              c22zem=c22zemBAB(m02,m12,m22)
              return
           endif
        endif

        if(abs(r1/r2-1.d0).lt.eps)then
           c22zem=c22zemABB(m02,m12,m22)
           return
        else
           c22zem=c22zemABC(m02,m12,m22)
           return
        endif

        write(*,*)'ERROR'

        return
        end


        real*8 function c12zem(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2,eps,zeromass
        real*8 c12zemABC,c12zemABB,c12zemBAB,c12zemBBA,c12zemAAA

        zeromass=1.d-20
        m02=max(zeromass,m02)
        m12=max(zeromass,m12)
        m22=max(zeromass,m22)
        r1=m12/m02
        r2=m22/m02
        eps=1.0d-2
        
        if(abs(r1-1.d0).lt.eps)then
           if(abs(r2-1.d0).lt.eps)then
              c12zem=c12zemAAA(m02,m12,m22)
              return
           else
              c12zem=c12zemBBA(m02,m12,m22)
              return
           endif
        endif

        if(abs(r2-1.d0).lt.eps)then
           if(abs(r1-1.d0).lt.eps)then
              c12zem=c12zemAAA(m02,m12,m22)
              return
           else
              c12zem=c12zemBAB(m02,m12,m22)
              return
           endif
        endif

        if(abs(r1/r2-1.d0).lt.eps)then
           c12zem=c12zemABB(m02,m12,m22)
           return
        else
           c12zem=c12zemABC(m02,m12,m22)
           return
        endif

        write(*,*)'ERROR'

        return
        end

        real*8 function c00zem(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2,eps,zeromass
        real*8 c00zemABC,c00zemABB,c00zemBAB,c00zemBBA,c00zemAAA

        zeromass=1.d-20
        m02=max(zeromass,m02)
        m12=max(zeromass,m12)
        m22=max(zeromass,m22)
        r1=m12/m02
        r2=m22/m02
        eps=1.0d-2
        
        if(abs(r1-1.d0).lt.eps)then
           if(abs(r2-1.d0).lt.eps)then
              c00zem=c00zemAAA(m02,m12,m22)
              return
           else
              c00zem=c00zemBBA(m02,m12,m22)
              return
           endif
        endif

        if(abs(r2-1.d0).lt.eps)then
           if(abs(r1-1.d0).lt.eps)then
              c00zem=c00zemAAA(m02,m12,m22)
              return
           else
              c00zem=c00zemBAB(m02,m12,m22)
              return
           endif
        endif

        if(abs(r1/r2-1.d0).lt.eps)then
           c00zem=c00zemABB(m02,m12,m22)
           return
        else
           c00zem=c00zemABC(m02,m12,m22)
           return
        endif

        write(*,*)'ERROR'

        return
        end




        real*8 function c0zemABC(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        r1=m12/m02
        r2=m22/m02
        c0zemABC=-((-(r1*log(r1))+r1*r2*log(r1)+r2*log(r2)-r1*r2
     &  *log(r2))/(m02*(-1+r1)*(r1-r2)*(-1+r2)))
        return
        end

        real*8 function c0zemABB(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        r1=m12/m02
        r2=m22/m02

        c0zemABB=(1+r1*(-1-log(r1))+log(r1)+r1*log(r1))/(m02*(-1
     &  +r1)**2)+((-r1+r2)**2*(-((-5.d-1+1/(2.d0*r1))/(-1+r1)**2)+(-1
     &  /(6.d0*r1**2)+1/(6.d0*r1))/(-1+r1)+(1+r1*(-1-log(r1))+log(r1)
     &  +r1*log(r1))/(-1+r1)**3))/(m02*(-1+r1))+((-r1+r2)*((-5.d-1+1
     &  /(2.d0*r1))/(-1+r1)-(1+r1*(-1-log(r1))+log(r1)+r1*log(r1))/(-1
     &  +r1)**2))/(m02*(-1+r1))

        return
        end

        real*8 function c0zemBAB(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02
        c0zemBAB=-((1-r1+r1*log(r1))/(m02*(-1+r1)**2))+((-1+r2)**2*(
     &  -((5.d-1-r1/2.d0)/(-1+r1)**2)-(-1.d0/6.d0+r1/6.d0)
     &  /(-1+r1)-(1-r1+r1*log(r1))/(-1+r1)**3))/(m02*(-1+r1))+((-1+r2)
     &  *(-((5.d-1-r1/2.d0)/(-1+r1))-(1-r1+r1*log(r1))/(-1+r1)**2))
     &  /(m02*(-1+r1))

        return
        end

        real*8 function c0zemBBA(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02

        c0zemBBA=-((-1+r2-r2*log(r2))/(m02*(1-r2)*(-1+r2)))+((-1+r1)**2
     &  *(-((1.d0/6.d0-r2/6.d0)/(1-r2))+(-5.d-1+r2/2.d0)/(1
     &  -r2)**2-(-1+r2-r2*log(r2))/(1-r2)**3))/(m02*(-1+r2))+((-1+r1)*(
     &  -((-5.d-1+r2/2.d0)/(1-r2))+(-1+r2-r2*log(r2))/(1-r2)**2))/(m02
     &  *(-1+r2))


        return
        end
 

        real*8 function c0zemAAA(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02
        c0zemAAA=-1/(2.d0*m02)+(-1+r1)/(6.d0*m02)-(-1+r1)**2/(1.2d1
     &  *m02)+(1/(6.d0*m02)-(-1+r1)/(1.2d1*m02)+(-1+r1)**2/(2.d1*m02))
     &  *(-1+r2)+(-1/(1.2d1*m02)+(-1+r1)/(2.d1*m02)-(-1+r1)**2/(3.d1
     &  *m02))*(-1+r2)**2


        return
        end
 

        real*8 function c1zemABC(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        r1=m12/m02
        r2=m22/m02
        c1zemABC=(r1**2-r1**3-r1*r2+r1**3*r2+r1*r2**2-r1**2*r2**2+r1**2
     &  *log(r1)-2*r1*r2*log(r1)+2*r1*r2**2*log(r1)-r1**2*r2**2*log(r1)
     &  +r2**2*log(r2)-2*r1*r2**2*log(r2)+r1**2*r2**2*log(r2))/(2.d0
     &  *m02*(-1+r1)**2*(r1-r2)**2*(-1+r2))
        return
        end
 
        real*8 function c1zemABB(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02

        c1zemABB=(1.5d0+r1-r1**2+log(r1)+2*r1*log(r1)-r1**2*log(r1)-2
     &  *r1*(1.5d0+log(r1))+r1**2*(1.5d0+log(r1)))/(2.d0*m02*(-1
     &  +r1)**3)+((-r1+r2)**2*(-((-2.0d0/3.0d0+1/(3.d0*r1)+r1
     &  /3.d0)/(-1+r1)**2)+(-1.0d0/12.0d0-1/(1.2d1*r1**2)+1
     &  /(6.d0*r1))/(-1+r1)+(1.5d0+r1-r1**2+log(r1)+2*r1*log(r1)-r1**2
     &  *log(r1)-2*r1*(1.5d0+log(r1))+r1**2*(1.5d0+log(r1)))/(-1
     &  +r1)**3))/(2.d0*m02*(-1+r1)**2)+((-r1+r2)*((-2.0d0/3.d0
     &  +1/(3.d0*r1)+r1/3.d0)/(-1+r1)-(1.5d0+r1-r1**2+log(r1)+2*r1
     &  *log(r1)-r1**2*log(r1)-2*r1*(1.5d0+log(r1))+r1**2*(1.5d0
     &  +log(r1)))/(-1+r1)**2))/(2.d0*m02*(-1+r1)**2)


        return
        end
        
        real*8 function c1zemBAB(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02

        c1zemBAB=(1-r1-r1**2+r1**3+2*r1*log(r1)-2*r1**2*log(r1))/(2.d0
     &  *m02*(-1+r1)**4)+((-1+r2)**2*((1.0d0/3.0d0-(2*r1)/3.d0
     &  +r1**2/3.d0)/(-1+r1)**2+(3*(1-r1-r1**2+r1**3+2*r1*log(r1)-2
     &  *r1**2*log(r1)))/(-1+r1)**4+(2*(1.5d0-2*r1+r1**2/2.d0+2*r1
     &  *log(r1)-r1**2*log(r1)))/(-1+r1)**3))/(2.d0*m02*(-1+r1)**2)+((
     &  -1+r2)*((2*(1-r1-r1**2+r1**3+2*r1*log(r1)-2*r1**2*log(r1)))/(-1
     &  +r1)**3+(1.5d0-2*r1+r1**2/2.d0+2*r1*log(r1)-r1**2*log(r1))/(-1
     &  +r1)**2))/(2.d0*m02*(-1+r1)**2)

        return
        end

        real*8 function c1zemBBA(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02
        c1zemBBA=(-5.d-1+2*r2-(3*r2**2)/2.d0+r2**2*log(r2))/(2.d0*m02
     &  *(1-r2)**2*(-1+r2))+((-1+r1)**2*((-2*(-2.0d0/3.0d0+(4
     &  *r2)/3.d0-(2*r2**2)/3.d0))/(1-r2)**3+(-1.0d0/12.0d0-r2
     &  /6.d0+r2**2/4.d0)/(1-r2)**2+(3*(-5.d-1+2*r2-(3*r2**2)/2.d0
     &  +r2**2*log(r2)))/(1-r2)**4))/(2.d0*m02*(-1+r2))+((-1+r1)*((
     &  -2.0d0/3.0d0+(4*r2)/3.d0-(2*r2**2)/3.d0)/(1-r2)**2-(2
     &  *(-5.d-1+2*r2-(3*r2**2)/2.d0+r2**2*log(r2)))/(1-r2)**3))/(2.d0
     &  *m02*(-1+r2))


        return
        end
 
        real*8 function c1zemAAA(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02
        c1zemAAA=1/(6.d0*m02)-(-1+r1)/(1.2d1*m02)+(-1+r1)**2/(2.d1*m02)
     &  +(-1/(2.4d1*m02)+(-1+r1)/(3.d1*m02)-(-1+r1)**2/(4.d1*m02))*(-1
     &  +r2)+(1/(6.d1*m02)-(-1+r1)/(6.d1*m02)+(-1+r1)**2/(7.d1*m02))*(
     &  -1+r2)**2

        return
        end
 
        real*8 function c2zemABC(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        r1=m12/m02
        r2=m22/m02
        c2zemABC=((r1-r2)**2*log(r1)+(-1+r1)*r2*(-((r1-r2)*(-1+r2))+(r1
     &  *(-2+r2)+r2)*log(r1/r2)))/(2.d0*m02*(-1+r1)*(r1-r2)**2*(-1
     &  +r2)**2)
        return
        end
 
        real*8 function c2zemABB(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02
        c2zemABB=((-1+r1)*r1*(1-(1+r1)/r1+(r1+(-2+r1)*r1)/(2.d0*r1**2))
     &  +log(r1))/(2.d0*m02*(-1+r1)**3)+((-r1+r2)**2*(((1+r1)/(2.d0
     &  *r1**2)-(r1+(-2+r1)*r1)/(3.d0*r1**3)+r1*(-(1+r1)/(3.d0*r1**3)
     &  +(r1+(-2+r1)*r1)/(4.d0*r1**4)))/(-1+r1)-(2*(1-(1+r1)/r1+(r1+(-2
     &  +r1)*r1)/(2.d0*r1**2)+r1*((1+r1)/(2.d0*r1**2)-(r1+(-2+r1)*r1)
     &  /(3.d0*r1**3))))/(-1+r1)**2+(3*((-1+r1)*r1*(1-(1+r1)/r1+(r1+(-2
     &  +r1)*r1)/(2.d0*r1**2))+log(r1)))/(-1+r1)**4))/(2.d0*m02*(-1
     &  +r1))+((-r1+r2)*((1-(1+r1)/r1+(r1+(-2+r1)*r1)/(2.d0*r1**2)+r1
     &  *((1+r1)/(2.d0*r1**2)-(r1+(-2+r1)*r1)/(3.d0*r1**3)))/(-1+r1)-(2
     &  *((-1+r1)*r1*(1-(1+r1)/r1+(r1+(-2+r1)*r1)/(2.d0*r1**2))
     &  +log(r1)))/(-1+r1)**3))/(2.d0*m02*(-1+r1))

        return
        end
 
        real*8 function c2zemBAB(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02
        c2zemBAB=(log(r1)+(-1+r1)*((1-r1)/2.d0-r1+(1+r1)*log(r1)))
     &  /(2.d0*m02*(-1+r1)**3)+((-1+r2)**2*(((-1-r1)/3.d0+(1-r1)/4.d0+(
     &  -1+r1)/3.d0+(1+r1)/2.d0)/(-1+r1)+(2*((1-r1)/2.d0+(-1+r1)/3.d0
     &  -r1+(1+r1)/2.d0))/(-1+r1)**2+(3*(log(r1)+(-1+r1)*((1-r1)/2.d0
     &  -r1+(1+r1)*log(r1))))/(-1+r1)**4))/(2.d0*m02*(-1+r1))+((-1+r2)
     &  *(((1-r1)/2.d0+(-1+r1)/3.d0-r1+(1+r1)/2.d0)/(-1+r1)+(2*(log(r1)
     &  +(-1+r1)*((1-r1)/2.d0-r1+(1+r1)*log(r1))))/(-1+r1)**3))/(2.d0
     &  *m02*(-1+r1))


        return
        end

        real*8 function c2zemBBA(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02
        c2zemBBA=((1-r2)**2+r2*((-1+r2)**2+(-2+2*r2)*log(1/r2)))/(2.d0
     &  *m02*(1-r2)**2*(-1+r2)**2)+((-1+r1)**2*((1+(1-r2)**2/3.d0+r2*(
     &  -2+(2-2*r2)/2.d0+r2)+(-2+2*r2)/2.d0)/(1-r2)**2-(2*(2-(1-r2)**2
     &  /2.d0-2*r2+r2*(-1+r2+(-2+r2)*log(1/r2))))/(1-r2)**3+(3*((1
     &  -r2)**2+r2*((-1+r2)**2+(-2+2*r2)*log(1/r2))))/(1-r2)**4))/(2.d0
     &  *m02*(-1+r2)**2)+((-1+r1)*((2-(1-r2)**2/2.d0-2*r2+r2*(-1+r2+(-2
     &  +r2)*log(1/r2)))/(1-r2)**2-(2*((1-r2)**2+r2*((-1+r2)**2+(-2+2
     &  *r2)*log(1/r2))))/(1-r2)**3))/(2.d0*m02*(-1+r2)**2)


        return
        end
 
        real*8 function c2zemAAA(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02
        c2zemAAA=1/(6.d0*m02)-(-1+r1)/(2.4d1*m02)+(-1+r1)**2/(6.d1*m02)
     &  +(-1/(1.2d1*m02)+(-1+r1)/(3.d1*m02)-(-1+r1)**2/(6.d1*m02))*(-1
     &  +r2)+(1/(2.d1*m02)-(-1+r1)/(4.d1*m02)+(-1+r1)**2/(7.d1*m02))*(
     &  -1+r2)**2

        return
        end
 
        real*8 function c11zemABC(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

       r1=m12/m02
        r2=m22/m02
        c11zemABC=-(-3*r1**3+4*r1**4-r1**5+8*r1**2*r2-9*r1**3*r2+r1**5
     &  *r2-5*r1*r2**2+9*r1**3*r2**2-4*r1**4*r2**2+5*r1*r2**3-8*r1**2
     &  *r2**3+3*r1**3*r2**3-2*r1**3*log(r1)+6*r1**2*r2*log(r1)-6*r1
     &  *r2**2*log(r1)+6*r1*r2**3*log(r1)-6*r1**2*r2**3*log(r1)+2*r1**3
     &  *r2**3*log(r1)+2*r2**3*log(r2)-6*r1*r2**3*log(r2)+6*r1**2*r2**3
     &  *log(r2)-2*r1**3*r2**3*log(r2))/(6.d0*m02*(-1+r1)**3*(r1-r2)**3
     &  *(-1+r2))


        return
        end

        real*8 function c11zemABB(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        real*8 t1,t2

        r1=m12/m02
        r2=m22/m02
        t1=(5*r1-8*r1**2+3*r1**3+6*r1*log(r1)-6*r1**2*log(r1)+2*r1**3
     &  *log(r1)+2*(11.0d0/6.0d0+log(r1))-6*r1
     &  *(11.0d0/6.0d0+log(r1))+6*r1**2*(11.0d0/6.0d0
     &  +log(r1))-2*r1**3*(11.0d0/6.0d0+log(r1)))/(6.d0*m02*(-1
     &  +r1)**4)
        t2=((-r1+r2)**2*((-3.d-1-1/(1.d1*r1**2)+3/(1.d1*r1)+r1/1.d1)/(
     &  -1+r1)-(-1.5d0+1/(2.d0*r1)+(3*r1)/2.d0-r1**2/2.d0)/(-1+r1)**2
     &  +(5*r1-8*r1**2+3*r1**3+6*r1*log(r1)-6*r1**2*log(r1)+2*r1**3
     &  *log(r1)+2*(11.0d0/6.0d0+log(r1))-6*r1
     &  *(11.0d0/6.0d0+log(r1))+6*r1**2*(11.0d0/6.0d0
     &  +log(r1))-2*r1**3*(11.0d0/6.0d0+log(r1)))/(-1+r1)**3))
     &  /(6.d0*m02*(-1+r1)**3)+((-r1+r2)*((-1.5d0+1/(2.d0*r1)+(3*r1)
     &  /2.d0-r1**2/2.d0)/(-1+r1)-(5*r1-8*r1**2+3*r1**3+6*r1*log(r1)-6
     &  *r1**2*log(r1)+2*r1**3*log(r1)+2*(11.0d0/6.0d0+log(r1))
     &  -6*r1*(11.0d0/6.0d0+log(r1))+6*r1**2
     &  *(11.0d0/6.0d0+log(r1))-2*r1**3*(11.0d0/6.0d0
     &  +log(r1)))/(-1+r1)**2))/(6.d0*m02*(-1+r1)**3)
        c11zemABB=t1+t2


        return
        end

 
        real*8 function c11zemBAB(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02
        c11zemBAB=-(2-r1-10*r1**2+16*r1**3-8*r1**4+r1**5+6*r1*log(r1)
     &  -12*r1**2*log(r1)+6*r1**3*log(r1))/(6.d0*m02*(-1+r1)**6)+((-1
     &  +r2)**2*(-((11.0d0/3.0d0-6*r1+3*r1**2-(2*r1**3)/3.d0+6
     &  *r1*log(r1)-6*r1**2*log(r1)+2*r1**3*log(r1))/(-1+r1)**3)-(3*(5
     &  -5*r1-9*r1**2+13*r1**3-4*r1**4+12*r1*log(r1)-18*r1**2*log(r1)+6
     &  *r1**3*log(r1)))/(-1+r1)**4-(6*(2-r1-10*r1**2+16*r1**3-8*r1**4
     &  +r1**5+6*r1*log(r1)-12*r1**2*log(r1)+6*r1**3*log(r1)))/(-1
     &  +r1)**5))/(6.d0*m02*(-1+r1)**3)+((-1+r2)*(-((5-5*r1-9*r1**2+13
     &  *r1**3-4*r1**4+12*r1*log(r1)-18*r1**2*log(r1)+6*r1**3*log(r1))
     &  /(-1+r1)**3)-(3*(2-r1-10*r1**2+16*r1**3-8*r1**4+r1**5+6*r1
     &  *log(r1)-12*r1**2*log(r1)+6*r1**3*log(r1)))/(-1+r1)**4))/(6.d0
     &  *m02*(-1+r1)**3)


        return
        end
        

        real*8 function c11zemBBA(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02
        c11zemBBA=-(-2.0d0/3.0d0+3*r2-6*r2**2+(11*r2**3)/3.d0-2*r2**3
     &  *log(r2))/(6.d0*m02*(1-r2)**3*(-1+r2))+((-1+r1)**2*(-((-9.d-1
     &  +(6*r2)/5.d0+(3*r2**2)/1.d1-(3*r2**3)/5.d0)/(1-r2)**3)+(3*(
     &  -1.5d0+(9*r2)/2.d0-(9*r2**2)/2.d0+(3*r2**3)/2.d0))/(1-r2)**4-(6
     &  *(-2.0d0/3.0d0+3*r2-6*r2**2+(11*r2**3)/3.d0-2*r2**3*log(r2)))
     &  /(1-r2)**5))/(6.d0*m02*(-1+r2))+((-1+r1)*(-((-1.5d0+(9*r2)/2.d0
     &  -(9*r2**2)/2.d0+(3*r2**3)/2.d0)/(1-r2)**3)+(3*(
     &  -2.0d0/3.0d0+3*r2-6*r2**2+(11*r2**3)/3.d0-2*r2**3
     &  *log(r2)))/(1-r2)**4))/(6.d0*m02*(-1+r2))


        return
        end
 
        real*8 function c11zemAAA(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02
        c11zemAAA=-1/(1.2d1*m02)+(-1+r1)/(2.d1*m02)-(-1+r1)**2/(3.d1
     &  *m02)+(1/(6.d1*m02)-(-1+r1)/(6.d1*m02)+(-1+r1)**2/(7.d1*m02))*(
     &  -1+r2)+(-1/(180.0d0*m02)+(-1+r1)/(140.0d0*m02)-(-1+r1)**2
     &  /(140.0d0*m02))*(-1+r2)**2

        return
        end

 
        real*8 function c22zemABC(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02
        c22zemABC=(2*(r1-r2)**3*log(r1)-(-1+r1)*r2*(-((-1+r2)*(-4*r1*(
     &  -2+r2)*r2+(-3+r2)*r2**2+r1**2*(-5+3*r2)))+2*(r1*(-3+r2)*r2
     &  +r2**2+r1**2*(3-3*r2+r2**2))*log(r1/r2)))/(6.d0*m02*(-1+r1)*(r1
     &  -r2)**3*(-1+r2)**3)
        return
        end
 
        real*8 function c22zemABB(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        real*8 t1,t2,t3,t4,t5,t6,t7

        r1=m12/m02
        r2=m22/m02
        t1=1/(6.d0*m02)
        t2=1/(-1+r1)
        t3=(-r1+r2)**2
        t4=-((1-2*r1*(-(1+r1+r1**2)/(3.d0*r1**3)+(2*r1+r1*(-3+2*r1)
     &  +r1**2*(-3+2*r1))/(4.d0*r1**4)-(r1**2+(-3+r1)*r1**2+r1**2*(3-3
     &  *r1+r1**2))/(5.d0*r1**5))-2*((1+r1+r1**2)/(2.d0*r1**2)-(2*r1+r1
     &  *(-3+2*r1)+r1**2*(-3+2*r1))/(3.d0*r1**3)+(r1**2+(-3+r1)*r1**2
     &  +r1**2*(3-3*r1+r1**2))/(4.d0*r1**4)))/(-1+r1)**2)
        t5=(3*(-4-2*(-((1+r1+r1**2)/r1)+(2*r1+r1*(-3+2*r1)+r1**2*(-3+2
     &  *r1))/(2.d0*r1**2)-(r1**2+(-3+r1)*r1**2+r1**2*(3-3*r1+r1**2))
     &  /(3.d0*r1**3))-r1*(-1+2*((1+r1+r1**2)/(2.d0*r1**2)-(2*r1+r1*(-3
     &  +2*r1)+r1**2*(-3+2*r1))/(3.d0*r1**3)+(r1**2+(-3+r1)*r1**2+r1**2
     &  *(3-3*r1+r1**2))/(4.d0*r1**4)))))/(-1+r1)**3-(6*(-((-1+r1)*r1
     &  *(4+2*(-((1+r1+r1**2)/r1)+(2*r1+r1*(-3+2*r1)+r1**2*(-3+2*r1))
     &  /(2.d0*r1**2)-(r1**2+(-3+r1)*r1**2+r1**2*(3-3*r1+r1**2))/(3.d0
     &  *r1**3))))-2*log(r1)))/(-1+r1)**5
        t6=((-r1+r2)*(-((-4-2*(-((1+r1+r1**2)/r1)+(2*r1+r1*(-3+2*r1)
     &  +r1**2*(-3+2*r1))/(2.d0*r1**2)-(r1**2+(-3+r1)*r1**2+r1**2*(3-3
     &  *r1+r1**2))/(3.d0*r1**3))-r1*(-1+2*((1+r1+r1**2)/(2.d0*r1**2)
     &  -(2*r1+r1*(-3+2*r1)+r1**2*(-3+2*r1))/(3.d0*r1**3)+(r1**2+(-3
     &  +r1)*r1**2+r1**2*(3-3*r1+r1**2))/(4.d0*r1**4))))/(-1+r1)**2)+(3
     &  *(-((-1+r1)*r1*(4+2*(-((1+r1+r1**2)/r1)+(2*r1+r1*(-3+2*r1)
     &  +r1**2*(-3+2*r1))/(2.d0*r1**2)-(r1**2+(-3+r1)*r1**2+r1**2*(3-3
     &  *r1+r1**2))/(3.d0*r1**3))))-2*log(r1)))/(-1+r1)**4))/(6.d0*m02
     &  *(-1+r1))
        t7=-(-((-1+r1)*r1*(4+2*(-((1+r1+r1**2)/r1)+(2*r1+r1*(-3+2*r1)
     &  +r1**2*(-3+2*r1))/(2.d0*r1**2)-(r1**2+(-3+r1)*r1**2+r1**2*(3-3
     &  *r1+r1**2))/(3.d0*r1**3))))-2*log(r1))/(6.d0*m02*(-1+r1)**4)
        c22zemABB=t1*t2*t3*(t4+t5)+t6+t7

        return
        end
 
        real*8 function c22zemBAB(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        real*8 t1,t2,t3

        r1=m12/m02
        r2=m22/m02
        t1=(-2*log(r1)+(-1+r1)*(-3-4*r1+3*r1**2-2*(-1-r1-r1**2+(2-r1
     &  -r1**2)/2.d0+(-1+2*r1-r1**2)/3.d0)-2*(-2+r1+r1**2+(1-2*r1
     &  +r1**2)/2.d0+(1+r1+r1**2)*log(r1))))/(6.d0*m02*(-1+r1)**4)
        t2=((-1+r2)**2*((1-2*((-1-r1-r1**2)/3.d0+(2-r1-r1**2)/4.d0+(-1
     &  +2*r1-r1**2)/5.d0)-2*((1-2*r1+r1**2)/4.d0+(-2+r1+r1**2)/3.d0+(1
     &  +r1+r1**2)/2.d0))/(-1+r1)**2+(3*(1-4*r1-2*(-1-r1-r1**2+(2-r1
     &  -r1**2)/2.d0+(-1+2*r1-r1**2)/3.d0)-2*((1-2*r1+r1**2)/4.d0+(-2
     &  +r1+r1**2)/3.d0+(1+r1+r1**2)/2.d0)))/(-1+r1)**3+(6*(-2*log(r1)
     &  +(-1+r1)*(-3-4*r1+3*r1**2-2*(-1-r1-r1**2+(2-r1-r1**2)/2.d0+(-1
     &  +2*r1-r1**2)/3.d0)-2*(-2+r1+r1**2+(1-2*r1+r1**2)/2.d0+(1+r1
     &  +r1**2)*log(r1)))))/(-1+r1)**5))/(6.d0*m02*(-1+r1))
        t3=((-1+r2)*((1-4*r1-2*(-1-r1-r1**2+(2-r1-r1**2)/2.d0+(-1+2*r1
     &  -r1**2)/3.d0)-2*((1-2*r1+r1**2)/4.d0+(-2+r1+r1**2)/3.d0+(1+r1
     &  +r1**2)/2.d0))/(-1+r1)**2+(3*(-2*log(r1)+(-1+r1)*(-3-4*r1+3
     &  *r1**2-2*(-1-r1-r1**2+(2-r1-r1**2)/2.d0+(-1+2*r1-r1**2)/3.d0)-2
     &  *(-2+r1+r1**2+(1-2*r1+r1**2)/2.d0+(1+r1+r1**2)*log(r1)))))/(-1
     &  +r1)**4))/(6.d0*m02*(-1+r1))
        c22zemBAB=t1+t2+t3

        return
        end
 
        real*8 function c22zemBBA(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        real*8 t1,t2,t3

        r1=m12/m02
        r2=m22/m02
        t1=(2*(1-r2)**3+r2*(-((-1+r2)*(5-3*r2+4*(-2+r2)*r2-(-3+r2)
     &  *r2**2))-2*(3-3*r2+(-3+r2)*r2+2*r2**2)*log(1/r2)))/(6.d0*m02*(1
     &  -r2)**3*(-1+r2)**3)
        t2=((-1+r1)**2*((6*(2*(1-r2)**3+r2*(-((-1+r2)*(5-3*r2+4*(-2+r2)
     &  *r2-(-3+r2)*r2**2))-2*(3-3*r2+(-3+r2)*r2+2*r2**2)*log(1/r2))))
     &  /(1-r2)**5+(2*(3*(1-r2)-(3*(1-r2)**2)/2.d0+(1-r2)**3/3.d0)+r2*(
     &  -((5-3*r2)*(-1+r2))-2*((-3+r2)*r2+(-3+3*r2-(-3+r2)*r2-2*r2**2)
     &  /2.d0+2*(3-3*r2+r2**2)+(3-3*r2+r2**2)*log(1/r2))))/(1-r2)**3-(3
     &  *(2*(3*(1-r2)**2-(1-r2)**3/2.d0)+r2*(-((-1+r2)*(4*(-2+r2)*r2-2
     &  *(-5+3*r2)))-2*(3-3*r2+(-3+r2)*r2+2*r2**2+((-3+r2)*r2+2*(3-3*r2
     &  +r2**2))*log(1/r2)))))/(1-r2)**4))/(6.d0*m02*(-1+r2)**3)
        t3=((-1+r1)*((-3*(2*(1-r2)**3+r2*(-((-1+r2)*(5-3*r2+4*(-2+r2)
     &  *r2-(-3+r2)*r2**2))-2*(3-3*r2+(-3+r2)*r2+2*r2**2)*log(1/r2))))
     &  /(1-r2)**4+(2*(3*(1-r2)**2-(1-r2)**3/2.d0)+r2*(-((-1+r2)*(4*(-2
     &  +r2)*r2-2*(-5+3*r2)))-2*(3-3*r2+(-3+r2)*r2+2*r2**2+((-3+r2)*r2
     &  +2*(3-3*r2+r2**2))*log(1/r2))))/(1-r2)**3))/(6.d0*m02*(-1
     &  +r2)**3)
        c22zemBBA=t1+t2+t3

        return
        end
 
        real*8 function c22zemAAA(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02
        c22zemAAA=-1/(1.2d1*m02)+(-1+r1)/(6.d1*m02)-(-1+r1)**2
     &  /(180.0d0*m02)+(1/(2.d1*m02)-(-1+r1)/(6.d1*m02)+(
     &  -1+r1)**2/(140.0d0*m02))*(-1+r2)+(-1/(3.d1*m02)+(
     &  -1+r1)/(7.d1*m02)-(-1+r1)**2/(140.0d0*m02))*(-1+r2)**2


        return
        end
        
        real*8 function c12zemABC(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        r1=m12/m02
        r2=m22/m02
        c12zemABC=((r1-r2)**3*log(r1)-(-1+r1)*((-1+r2)*(r1**3*(-1+r2)
     &  +r1**2*r2+r2**3-r1*r2**2*(1+r2))-(-1+r1)*r2**2*(r2+r1*(-3+2
     &  *r2))*log(r1/r2)))/(6.d0*m02*(-1+r1)**2*(r1-r2)**3*(-1+r2)**2)
        return
        end
 
        real*8 function c12zemABB(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        real*8 t1,t2,t3

        r1=m12/m02
        r2=m22/m02
        t1=((-r1+r2)**2*(-(1+2*r1)/(2.d0*r1**2)+(r1+r1*(-3+2*r1))/(5.d0
     &  *r1**3)+(r1+r1*(-3+2*r1)+2*r1*(1+2*r1))/(3.d0*r1**3)-(r1**2*(1
     &  +2*r1)+2*r1*(r1+r1*(-3+2*r1)))/(4.d0*r1**4)+(2*(-1+r1-(-1+r1)
     &  *((1+2*r1)/r1-(r1+r1*(-3+2*r1))/(4.d0*r1**2)-(r1+r1*(-3+2*r1)+2
     &  *r1*(1+2*r1))/(2.d0*r1**2)+(r1**2*(1+2*r1)+2*r1*(r1+r1*(-3+2
     &  *r1)))/(3.d0*r1**3))))/(-1+r1)**2-(3*((-1+r1)*(-((1-r1)*(-1
     &  +r1))-3*r1-(-1-3*r1)*r1-(-1+r1)*((r1+r1*(-3+2*r1))/(3.d0*r1)
     &  +(r1+r1*(-3+2*r1)+2*r1*(1+2*r1))/r1-(r1**2*(1+2*r1)+2*r1*(r1+r1
     &  *(-3+2*r1)))/(2.d0*r1**2)))-log(r1)))/(-1+r1)**4))/(6.d0*m02*(
     &  -1+r1)**2)
        t2=((-r1+r2)*(-((-1+r1-(-1+r1)*((1+2*r1)/r1-(r1+r1*(-3+2*r1))
     &  /(4.d0*r1**2)-(r1+r1*(-3+2*r1)+2*r1*(1+2*r1))/(2.d0*r1**2)
     &  +(r1**2*(1+2*r1)+2*r1*(r1+r1*(-3+2*r1)))/(3.d0*r1**3)))/(-1
     &  +r1))+(2*((-1+r1)*(-((1-r1)*(-1+r1))-3*r1-(-1-3*r1)*r1-(-1+r1)
     &  *((r1+r1*(-3+2*r1))/(3.d0*r1)+(r1+r1*(-3+2*r1)+2*r1*(1+2*r1))
     &  /r1-(r1**2*(1+2*r1)+2*r1*(r1+r1*(-3+2*r1)))/(2.d0*r1**2)))
     &  -log(r1)))/(-1+r1)**3))/(6.d0*m02*(-1+r1)**2)
        t3=-((-1+r1)*(-((1-r1)*(-1+r1))-3*r1-(-1-3*r1)*r1-(-1+r1)*((r1
     &  +r1*(-3+2*r1))/(3.d0*r1)+(r1+r1*(-3+2*r1)+2*r1*(1+2*r1))/r1
     &  -(r1**2*(1+2*r1)+2*r1*(r1+r1*(-3+2*r1)))/(2.d0*r1**2)))
     &  -log(r1))/(6.d0*m02*(-1+r1)**4)
        c12zemABB=t1+t2+t3

        return
        end

        real*8 function c12zemBAB(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        real*8 t1,t2,t3

        r1=m12/m02
        r2=m22/m02
        t1=(3*(-1+r1)*log(r1)+(-1+r1)*(-3+5*r1-r1**2-r1**3-(-1+r1)*(1
     &  +(3*(1-r1))/2.d0+2*r1-(1-r1+2*(1+2*r1))*log(r1))))/(6.d0*m02*(
     &  -1+r1)**5)
        t2=((-1+r2)**2*((-1+r1-(-1+r1)*(1+(-1+r1)/4.d0+2*r1+(1+2*(1-r1)
     &  +2*r1)/3.d0+(-1+r1-2*(1+2*r1))/2.d0))/(-1+r1)**2+(3*(-log(r1)+(
     &  -1+r1)*(-3+4*r1-(-1+r1)*(1+(-1-2*(1-r1)-2*r1)/2.d0+(1-r1)/3.d0
     &  -r1+2*(1+2*r1)-(1+2*r1)*log(r1)))))/(-1+r1)**4+(6*(3*(-1+r1)
     &  *log(r1)+(-1+r1)*(-3+5*r1-r1**2-r1**3-(-1+r1)*(1+(3*(1-r1))
     &  /2.d0+2*r1-(1-r1+2*(1+2*r1))*log(r1)))))/(-1+r1)**5))/(6.d0*m02
     &  *(-1+r1)**2)
        t3=((-1+r2)*((-log(r1)+(-1+r1)*(-3+4*r1-(-1+r1)*(1+(-1-2*(1-r1)
     &  -2*r1)/2.d0+(1-r1)/3.d0-r1+2*(1+2*r1)-(1+2*r1)*log(r1))))/(-1
     &  +r1)**3+(3*(3*(-1+r1)*log(r1)+(-1+r1)*(-3+5*r1-r1**2-r1**3-(-1
     &  +r1)*(1+(3*(1-r1))/2.d0+2*r1-(1-r1+2*(1+2*r1))*log(r1)))))/(-1
     &  +r1)**4))/(6.d0*m02*(-1+r1)**2)
        c12zemBAB=t1+t2+t3

        return
        end


        real*8 function c12zemBBA(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        real*8 t1,t2,t3

        r1=m12/m02
        r2=m22/m02
        t1=(3*(1-r2)**2-(1-r2)**3/2.d0-(-1+r2)*(3*(-1+r2)+2*r2-r2**2*(1
     &  +r2))+r2**2*(-3+3*r2)*log(1/r2))/(6.d0*m02*(1-r2)**3*(-1+r2)**2)
        t2=((-1+r1)**2*((1-(3*(1-r2))/2.d0+(1-r2)**2-(1-r2)**3/4.d0-(-1
     &  +r2)**2-r2**2*(3-2*r2+(-3+3*r2)/2.d0))/(1-r2)**3+(6*(3*(1
     &  -r2)**2-(1-r2)**3/2.d0-(-1+r2)*(3*(-1+r2)+2*r2-r2**2*(1+r2))
     &  +r2**2*(-3+3*r2)*log(1/r2)))/(1-r2)**5-(3*(3*(1-r2)-(3*(1
     &  -r2)**2)/2.d0+(1-r2)**3/3.d0-(-1+r2)*(3*(-1+r2)+r2)-r2**2*(3-3
     &  *r2-(-3+2*r2)*log(1/r2))))/(1-r2)**4))/(6.d0*m02*(-1+r2)**2)
        t3=((-1+r1)*((-3*(3*(1-r2)**2-(1-r2)**3/2.d0-(-1+r2)*(3*(-1+r2)
     &  +2*r2-r2**2*(1+r2))+r2**2*(-3+3*r2)*log(1/r2)))/(1-r2)**4+(3*(1
     &  -r2)-(3*(1-r2)**2)/2.d0+(1-r2)**3/3.d0-(-1+r2)*(3*(-1+r2)+r2)
     &  -r2**2*(3-3*r2-(-3+2*r2)*log(1/r2)))/(1-r2)**3))/(6.d0*m02*(-1
     &  +r2)**2)
        c12zemBBA=t1+t2+t3


        return
        end
 
        real*8 function c12zemAAA(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2

        r1=m12/m02
        r2=m22/m02
        c12zemAAA=-1/(2.4d1*m02)+(-1+r1)/(6.d1*m02)-(-1+r1)**2/(1.2d2
     &  *m02)+(1/(6.d1*m02)-(-1+r1)/(9.d1*m02)+(-1+r1)**2
     &  /(140.0d0*m02))*(-1+r2)+(-1/(1.2d2*m02)+(-1+r1)
     &  /(140.0d0*m02)-(3*(-1+r1)**2)/(560.0d0*m02))*(-1
     &  +r2)**2

        return
        end

        real*8 function c00zemABC(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        real*8 Delta,mu2,lbd2
        common/UVIRPAR/Delta,mu2,lbd2

        r1=m12/m02
        r2=m22/m02
        c00zemABC=(-2*(-1+r1)*(r1-r2)*(-1+r2)*log(m02/mu2)-2*r1**2*(-1
     &  +r2)*log(r1)+(-1+r1)*((3+2*Delta)*(r1-r2)*(-1+r2)+2*r2**2
     &  *log(r2)))/(8.d0*(-1+r1)*(r1-r2)*(-1+r2))

        return
        end

        real*8 function c00zemABB(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        real*8 Delta,mu2,lbd2
        common/UVIRPAR/Delta,mu2,lbd2
 
        r1=m12/m02
        r2=m22/m02
        c00zemABB=-(-2*(1-r1)*(-1+r1)*log(m02/mu2)-2*r1**2*log(r1)+(-1
     &  +r1)*((3+2*Delta)*(1-r1)+2*(r1+2*r1*log(r1))))/(8.d0*(-1
     &  +r1)**2)+((-r1+r2)**2*(-2/(3.d0*r1)+(2*(-1+r1)*log(m02/mu2)+(-1
     &  +r1)*(-3-2*Delta+2*(1.5d0+log(r1))))/(-1+r1)**2-(-2*(1-r1)*(-1
     &  +r1)*log(m02/mu2)-2*r1**2*log(r1)+(-1+r1)*((3+2*Delta)*(1-r1)+2
     &  *(r1+2*r1*log(r1))))/(-1+r1)**3))/(8.d0*(-1+r1))+((-r1+r2)*(
     &  -((2*(-1+r1)*log(m02/mu2)+(-1+r1)*(-3-2*Delta+2*(1.5d0
     &  +log(r1))))/(-1+r1))+(-2*(1-r1)*(-1+r1)*log(m02/mu2)-2*r1**2
     &  *log(r1)+(-1+r1)*((3+2*Delta)*(1-r1)+2*(r1+2*r1*log(r1))))/(-1
     &  +r1)**2))/(8.d0*(-1+r1))

        return
        end
 
        real*8 function c00zemBAB(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        real*8 Delta,mu2,lbd2
        common/UVIRPAR/Delta,mu2,lbd2

        r1=m12/m02
        r2=m22/m02
        c00zemBAB=((2+(3+2*Delta)*(-1+r1))*(-1+r1)-2*(-1+r1)**2*log(m02
     &  /mu2)-2*r1**2*log(r1))/(8.d0*(-1+r1)**2)+((-1+r2)**2
     &  *(2.d0/3.d0+(-2*Delta*(-1+r1)+2*(-1+r1)*log(m02
     &  /mu2))/(-1+r1)**2+((2+(3+2*Delta)*(-1+r1))*(-1+r1)-2*(-1+r1)**2
     &  *log(m02/mu2)-2*r1**2*log(r1))/(-1+r1)**3))/(8.d0*(-1+r1))+((-1
     &  +r2)*((-2*Delta*(-1+r1)+2*(-1+r1)*log(m02/mu2))/(-1+r1)+((2+(3
     &  +2*Delta)*(-1+r1))*(-1+r1)-2*(-1+r1)**2*log(m02/mu2)-2*r1**2
     &  *log(r1))/(-1+r1)**2))/(8.d0*(-1+r1))
 
        return
        end

        real*8 function c00zemBBA(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        real*8 Delta,mu2,lbd2
        common/UVIRPAR/Delta,mu2,lbd2

        r1=m12/m02
        r2=m22/m02
        c00zemBBA=(-2*(-1+r2)+(3+2*Delta)*(1-r2)*(-1+r2)-2*(1-r2)*(-1
     &  +r2)*log(m02/mu2)+2*r2**2*log(r2))/(8.d0*(1-r2)*(-1+r2))+((-1
     &  +r1)**2*((-2*(-1+r2))/(3.d0*(1-r2))-(-3*(-1+r2)+(3+2*Delta)*(-1
     &  +r2)-2*(-1+r2)*log(m02/mu2))/(1-r2)**2+(-2*(-1+r2)+(3+2*Delta)
     &  *(1-r2)*(-1+r2)-2*(1-r2)*(-1+r2)*log(m02/mu2)+2*r2**2*log(r2))
     &  /(1-r2)**3))/(8.d0*(-1+r2))+((-1+r1)*((-3*(-1+r2)+(3+2*Delta)*(
     &  -1+r2)-2*(-1+r2)*log(m02/mu2))/(1-r2)-(-2*(-1+r2)+(3+2*Delta)
     &  *(1-r2)*(-1+r2)-2*(1-r2)*(-1+r2)*log(m02/mu2)+2*r2**2*log(r2))
     &  /(1-r2)**2))/(8.d0*(-1+r2))

 
        return
        end

        real*8 function c00zemAAA(m02,m12,m22)
        implicit none
        real*8 m02,m12,m22
        real*8 r1,r2
        real*8 Delta,mu2,lbd2
        common/UVIRPAR/Delta,mu2,lbd2

        r1=m12/m02
        r2=m22/m02
        c00zemAAA=(1-r1)/1.2d1+(-1+r1)**2/4.8d1+(-1.d0/12.d0
     &  +(-1+r1)/4.8d1-(-1+r1)**2/1.2d2)*(-1+r2)+(1.d0/48.d0
     &  +(1-r1)/1.2d2+(-1+r1)**2/2.4d2)*(-1+r2)**2+(2*Delta-2*log(m02
     &  /mu2))/8.d0

        return
        end

        real*8 function b0zemAB(m02,m12)
        implicit none
        real*8 m02,m12
        real*8 r
        real*8 Delta,mu2,lbd2
        common/UVIRPAR/Delta,mu2,lbd2

        r=m12/m02
        b0zemAB=(-1-Delta+r+Delta*r+log(m02/mu2)-r*log(m02/mu2)-r
     &  *log(r))/(-1+r)

        return
        end

        real*8 function b0zemAA(m02,m12)
        implicit none
        real*8 m02,m12
        real*8 r
        real*8 Delta,mu2,lbd2
        common/UVIRPAR/Delta,mu2,lbd2

        r=m12/m02
        b0zemAA=Delta+(1-r)/2.d0+(-1+r)**2/6.d0-log(m02/mu2)

        return
        end

        real*8 function b1zemAB(m02,m12)
        implicit none
        real*8 m02,m12
        real*8 r
        real*8 Delta,mu2,lbd2
        common/UVIRPAR/Delta,mu2,lbd2

        r=m12/m02
        b1zemAB=(-3-2*Delta+4*r+4*Delta*r-r**2-2*Delta*r**2+2*log(m02
     &  /mu2)-4*r*log(m02/mu2)+2*r**2*log(m02/mu2)-4*r*log(r)+2*r**2
     &  *log(r))/(4.d0*(-1+r)**2)

        return
        end

        real*8 function b1zemAA(m02,m12)
        implicit none
        real*8 m02,m12
        real*8 r
        real*8 Delta,mu2,lbd2
        common/UVIRPAR/Delta,mu2,lbd2


        r=m12/m02
        b1zemAA=(-1+r)/3.d0-(-1+r)**2/8.d0+(-2*Delta+2*log(m02/mu2))
     &  /4.d0

        return
        end
